==> scffld-1.2.2.tgz: package/plopfile.js <==
module.exports = function (plop) {
    // controller generator
    plop.setGenerator('install', {
        description: 'Install scffld into root of your project',
        prompts: [{
            type: 'input',
            name: 'buildDir',
            message:
                "Hello! Welcome to: \n\n\n" +
                "███████╗ ██████╗███████╗███████╗██╗     ██████╗ \n" +
                "██╔════╝██╔════╝██╔════╝██╔════╝██║     ██╔══██╗\n" +
                "███████╗██║     █████╗  █████╗  ██║     ██║  ██║\n" +
                "╚════██║██║     ██╔══╝  ██╔══╝  ██║     ██║  ██║\n" +
                "███████║╚██████╗██║     ██║     ███████╗██████╔╝\n" +
                "╚══════╝ ╚═════╝╚═╝     ╚═╝     ╚══════╝╚═════╝ \n\n" +
                "Please specifiy your build directory or press enter for default:",
            default: 'dist'
        }, {
                type: 'list',
                name: 'cssPreprocessor',
                message: 'What CSS Preprocessor would you like to use?',
                choices: [
                    {name: 'SASS/SCSS', value: 'sass', checked: true},
                    {name: 'LESS', value: 'less'}
                ]
        }],
        actions: [{
            type: 'add',
            path: 'test.babelrc',
            templateFile: __dirname + '/.babelrc'
        },{
            type: 'add',
            path: 'test.editorconfig',
            templateFile: __dirname + '/.editorconfig'
        },{
            type: 'add',
            path: 'test.gulpfile.babel.js',
            templateFile: __dirname + '/gulpfile.babel.js'
        },
        function addConfigToPackageJson(answers) {
            var fs = require('fs');
            var pjson = require('./package.json');
            var configFilePath = __dirname + '/templates/config.json';

            if (fs.existsSync(configFilePath)) {

                var config = plop.renderString(
                    fs.readFileSync(configFilePath, "utf8"),
                    answers
                );

                pjson.scffld2 = JSON.parse(config);
                fs.writeFile('./package.json', JSON.stringify(pjson, null, 2), function (err) {
                  if (err) return console.log(err);
                });

                // console.log(config);
                return 'Added scffld config to package.json';
            } else {
                return 'Config template not found!';
            }

        }]
    });
};

==> scffld-1.2.5.tgz: package/plopfile.js <==
var path = require('path');

module.exports = function (plop) {
    var dest  =  plop.getPlopfilePath().includes('node_modules') ? '../../' : './'

    // controller generator
    plop.setGenerator('install', {
        description: 'Install scffld into root of your project',
        prompts: [{
            type: 'input',
            name: 'buildDir',
            message:
                "Hello! Welcome to: \n\n\n" +
                "███████╗ ██████╗███████╗███████╗██╗     ██████╗ \n" +
                "██╔════╝██╔════╝██╔════╝██╔════╝██║     ██╔══██╗\n" +
                "███████╗██║     █████╗  █████╗  ██║     ██║  ██║\n" +
                "╚════██║██║     ██╔══╝  ██╔══╝  ██║     ██║  ██║\n" +
                "███████║╚██████╗██║     ██║     ███████╗██████╔╝\n" +
                "╚══════╝ ╚═════╝╚═╝     ╚═╝     ╚══════╝╚═════╝ \n\n" +
                "Please specifiy your build directory or press enter for default:",
            default: 'dist'
        }, {
                type: 'list',
                name: 'cssPreprocessor',
                message: 'What CSS Preprocessor would you like to use?',
                choices: [
                    {name: 'SASS/SCSS', value: 'sass', checked: true},
                    {name: 'LESS', value: 'less'}
                ]
        }],
        actions: [{
            type: 'add',
            path: path.join(dest, '.babelrc'),
            templateFile: __dirname + '/.babelrc'
        },{
            type: 'add',
            path: path.join(dest, '.editorconfig'),
            templateFile: __dirname + '/.editorconfig'
        },{
            type: 'add',
            path: path.join(dest, 'gulpfile.babel.js'),
            templateFile: __dirname + '/gulpfile.babel.js'
        },
        function addConfigToPackageJson(answers) {
            var fs    = require('fs');
            var pjson = require(path.join(dest, 'package.json'));
            var configFilePath = __dirname + '/templates/config.json';

            if (fs.existsSync(configFilePath)) {

                //- Parse Scffld Config
                var config = JSON.parse(plop.renderString(
                    fs.readFileSync(configFilePath, "utf8"),
                    answers
                ));

                //- Add it to project package.json
                pjson.scffld = config.scffld;

                //- Update devDependencies if not present.
                pjson.devDependencies = pjson.devDependencies || {};
                for (var key in config.devDependencies) {
                    if (!pjson.devDependencies.hasOwnProperty(key)) {
                        pjson.devDependencies[key] = config.devDependencies[key];
                    }
                }

                //- Save changes.
                fs.writeFile(path.join(dest, 'package.json'), JSON.stringify(pjson, null, 2), function (err) {
                  if (err) return console.log(err);
                });

                // console.log(config);
                return 'Added scffld config to package.json';
            } else {
                return 'Config template not found!';
            }

        }]
    });
};
